@@ -12,11 +12,6 @@
 static inline
 _syscall1(int,close,int,fd)
 
-#if 0
-static inline
-_syscall2(int,stat,const char *,filename,struct stat *,stat_buf)
-#endif
-
 /*
  * opendir just makes an open() call - it return NULL if it fails
  * (open sets errno), otherwise it returns a DIR * pointer.
