@@ -21,8 +21,6 @@ static char sccsid[] = "@(#)gethostnamadr.c	6.39 (Berkeley) 1/4/90";
 
 #include "inetprivate.h"
 #include <syslog.h>
-#include <errno.h>
-#include <netdb.h>
 
 #if defined(USE_OPTIONS_H)
 # include "res_options.h"
@@ -123,6 +121,13 @@ typedef union {
     char ac;
 } align;
 
+#ifdef SHLIB
+extern int h_errno;
+#else
+extern int h_errno;
+#endif
+extern int errno;
+
 #if NLS
 #include "nl_types.h"
 #endif
@@ -330,7 +335,7 @@ init_services()
 
 			for (cp=buf; cp && *cp && isspace(*cp); cp++);
 			if  (cp && *cp) {
-			memmove(buf, cp, strlen(cp) + 1);
+			strcpy(buf,cp);
 			if (checkbuf(buf, CMD_ORDER)) {
 				cp = strpbrk(buf, " \t");
 				if (!cp 
@@ -347,11 +352,9 @@ init_services()
 						cp++;
 					dp = strpbrk(cp, TOKEN_SEPARATORS);
 					if (dp) *dp = '\0';
-					if (checkbuf(cp, ORD_BIND)) {
+					if (checkbuf(cp, ORD_BIND))
 						service_order[cc++] = SERVICE_BIND;
-						if (!(_res.options & RES_INIT))
-							res_init();
-					} else if (checkbuf(cp, ORD_HOSTS))
+					else if (checkbuf(cp, ORD_HOSTS))
 						service_order[cc++] = SERVICE_HOSTS;
 					else if (checkbuf(cp, ORD_NIS))
 						service_order[cc++] = SERVICE_NIS;
@@ -475,7 +478,7 @@ init_services()
                                     if ( cp = strpbrk(buf, " \t") )
                                     {
 					while (*cp == ' ' || *cp == '\t') cp++;
-                                        if (*cp)
+                                        if (cp)
                                         {
                                             (void) strcpy(tdp,cp);
                                             trimdomain[numtrimdomains++]=tdp;
@@ -508,11 +511,9 @@ init_services()
 		cc=0;
 		if(NULL!=(cp=strtok(cp, TOKEN_SEPARATORS))){
 			do{
-				if(checkbuf(cp, ORD_BIND)) {
+				if(checkbuf(cp, ORD_BIND))
 					service_order[cc++] = SERVICE_BIND;
-					if (!(_res.options & RES_INIT))
-						res_init();
-				} else if (checkbuf(cp, ORD_HOSTS))
+				else if (checkbuf(cp, ORD_HOSTS))
 					service_order[cc++] = SERVICE_HOSTS;
 				else if (checkbuf(cp, ORD_NIS))
 					service_order[cc++] = SERVICE_NIS;
@@ -579,6 +580,8 @@ init_services()
 	}
 
 	service_done = 1;
+	if (!(_res.options & RES_INIT))
+		res_init();
 }
 
 static struct hostent *
@@ -597,9 +600,7 @@ getanswer(answer, anslen, qname, qclass, qtype)
 	int haveanswer, had_error;
 	int toobig = 0;
 	char tbuf[MAXDNAME+1];
-	const char *tname;
 
-	tname = qname;
 	host.h_name = NULL;
 	eom = answer->buf + anslen;
 	/*
@@ -701,25 +702,6 @@ getanswer(answer, anslen, qname, qclass, qtype)
 			buflen -= n;
 			continue;
 		}
-		if (qtype == T_PTR && type == T_CNAME) {
-			n = dn_expand(answer->buf, eom, cp, tbuf, sizeof tbuf);
-                        if (n < 0) {
-				had_error++;
-                                continue;
-                        }
-                        cp += n;
-                        /* Get canonical name. */
-                        n = strlen(tbuf) + 1;   /* for the \0 */
-                        if (n > buflen) {
-				had_error++;
-                                continue;
-                        }
-                        strcpy(bp, tbuf);
-                        tname = bp;
-                        bp += n;
-                        buflen -= n;
-                        continue;
-                }
 		if (type != qtype) {
 			syslog(LOG_NOTICE|LOG_AUTH,
 #if NLS
@@ -734,7 +716,7 @@ getanswer(answer, anslen, qname, qclass, qtype)
 		}
 		switch (type) {
 		case T_PTR:
-			if (strcasecmp(tname, bp) != 0) {
+			if (strcasecmp(qname, bp) != 0) {
 				syslog(LOG_NOTICE|LOG_AUTH,
 #if NLS
 	       catgets(_libc_cat, NetMiscSet, NetMiscAskedForGot, AskedForGot),
@@ -878,10 +860,7 @@ gethostent ()
 	if (h_addr_ptrs[1] && reorder)
 	  reorder_addrs(hp);
 	if (hp)
-	{
-	  h_errno = NETDB_SUCCESS;
 	  return hp;
-	}
 	h_errno = HOST_NOT_FOUND;
 	break;
 
@@ -891,10 +870,7 @@ gethostent ()
 	if (h_addr_ptrs[1] && reorder)
 	  reorder_addrs(hp);
 	if (hp)
-	{
-	  h_errno = NETDB_SUCCESS;
 	  return hp;
-	}
 	h_errno = HOST_NOT_FOUND;
 	break;
 #endif /* NIS */
@@ -966,55 +942,28 @@ gethostbyname(const char *name)
 				if (_res.options & RES_DEBUG)
 					printf("res_search failed\n");
 #endif
-				break;
 			}
 			hp = getanswer(&buf, n, name, C_IN, T_A);
 			if (h_addr_ptrs[1] && reorder)
 				reorder_addrs(hp);
 			if (hp)
-			{
-				h_errno = NETDB_SUCCESS;
 				return trim_domains(hp);
-			}
 			break;
 		case SERVICE_HOSTS:
-			if (*trimdomain) {			
-				char *p;
-				p = strdup(name);
-				dotrimdomain(p);
-				hp = _gethtbyname(p);
-				free(p);
-			}
-			else
-			{
-				hp = _gethtbyname(name);
-			}
+			hp = _gethtbyname(name);
 			if (h_addr_ptrs[1] && reorder)
 				reorder_addrs(hp);
 			if (hp)
-			{
-				h_errno = NETDB_SUCCESS;
-				return trim_domains(hp);
-			}
+				return hp;
 			h_errno = HOST_NOT_FOUND;
 			break;
 #ifdef NIS
 		case SERVICE_NIS:
-			if (*trimdomain) {			
-				char *p;
-				p = strdup(name);
-				dotrimdomain(p);
-				hp = _getnishost(p, "hosts.byname");
-				free(p);
-			} else
-				hp = _getnishost(name, "hosts.byname");
+			hp = _getnishost(name, "hosts.byname");
 			if (h_addr_ptrs[1] && reorder)
 				reorder_addrs(hp);
 			if (hp)
-			{
-				h_errno = NETDB_SUCCESS;
-				return trim_domains(hp);
-			}
+				return hp;
 			h_errno = HOST_NOT_FOUND;
 			break;
 #endif /* NIS */
@@ -1108,17 +1057,11 @@ gethostbyaddr(const char *addr, int len, int type)
 					for (addrs = hp->h_addr_list;
 						*addrs; addrs++){
 						if (!bcmp(addrs[0], addr, len))
-						{
-							h_errno = NETDB_SUCCESS;
 							return trim_domains(hp);
-						}
 					}
 #else
 					if (!bcmp(hp->h_addr, addr, len)))
-					{
-						h_errno = NETDB_SUCCESS;
 						return trim_domains(hp);
-					}
 #endif
 					/* We've been spoofed */
 					h_errno = HOST_NOT_FOUND;
@@ -1149,7 +1092,6 @@ gethostbyaddr(const char *addr, int len, int type)
 #if BSD < 43 && !defined(h_addr)	/* new-style hostent structure */
 				hp->h_addr = h_addr_ptrs[0];
 #endif
-				h_errno = NETDB_SUCCESS;
 				return trim_domains(hp);
 			}
 			h_errno = HOST_NOT_FOUND;
@@ -1157,10 +1099,7 @@ gethostbyaddr(const char *addr, int len, int type)
 		case SERVICE_HOSTS:
 			hp = _gethtbyaddr(addr, len, type);
 			if (hp)
-			{
-				h_errno = NETDB_SUCCESS;
 				return hp;
-			}
 			h_errno = HOST_NOT_FOUND;
 			break;
 #ifdef NIS
@@ -1172,10 +1111,7 @@ gethostbyaddr(const char *addr, int len, int type)
 				      ((unsigned)addr[3] & 0xff));
 			hp = _getnishost(qbuf, "hosts.byaddr");
 			if (hp)
-			{
-				h_errno = NETDB_SUCCESS;
 				return hp;
-			}
 			h_errno = HOST_NOT_FOUND;
 			break;
 #endif /* NIS */
