@@ -64,37 +64,55 @@ static char rcsid[] = "res_debug.c,v 1.2 1995/05/06 14:12:41 hjl Exp";
 #include <arpa/nameser.h>
 
 #include <stdio.h>
-#include <netdb.h>
 #include <resolv.h>
 #include <string.h>
 
 #include "res_options.h"
 
-extern const char *_res_opcodes[];
-extern const char *_res_resultcodes[];
+const char *_res_opcodes[] = {
+	"QUERY",
+	"IQUERY",
+	"CQUERYM",
+	"CQUERYU",	/* experimental */
+	"NOTIFY",	/* experimental */
+	"5",
+	"6",
+	"7",
+	"8",
+	"UPDATEA",
+	"UPDATED",
+	"UPDATEDA",
+	"UPDATEM",
+	"UPDATEMA",
+	"ZONEINIT",
+	"ZONEREF",
+};
 
-#ifdef __ELF__
-#pragma weak fp_query = __fp_query
-#pragma weak fp_nquery = __fp_nquery
-#pragma weak fp_resstat = __fp_resstat
-#pragma weak p_cdname = __p_cdname
-#pragma weak p_cdnname = __p_cdnname
-#pragma weak p_class = __p_class
-#pragma weak p_fqname = __p_fqname
-#pragma weak p_option = __p_option
-#pragma weak p_query = __p_query
-#pragma weak p_rr = __p_rr
-#pragma weak p_time = __p_time
-#pragma weak p_type = __p_type
-#endif
+const char *_res_resultcodes[] = {
+	"NOERROR",
+	"FORMERR",
+	"SERVFAIL",
+	"NXDOMAIN",
+	"NOTIMP",
+	"REFUSED",
+	"6",
+	"7",
+	"8",
+	"9",
+	"10",
+	"11",
+	"12",
+	"13",
+	"14",
+	"NOCHANGE",
+};
+
+static char retbuf[16];
 
-/* XXX: we should use getservbyport() instead. */
 static const char *
 dewks(wks)
 	int wks;
 {
-	static char nbuf[20];
-
 	switch (wks) {
 	case 5: return "rje";
 	case 7: return "echo";
@@ -142,17 +160,14 @@ dewks(wks)
 	case 161: return "snmp";
 	case 162: return "snmp-trap";
 	case 170: return "print-srv";
-	default: (void) sprintf(nbuf, "%d", wks); return (nbuf);
+	default: (void) sprintf(retbuf, "%d", wks); return (retbuf);
 	}
 }
 
-/* XXX: we should use getprotobynumber() instead. */
 static const char *
 deproto(protonum)
 	int protonum;
 {
-	static char nbuf[20];
-
 	switch (protonum) {
 	case 1: return "icmp";
 	case 2: return "igmp";
@@ -166,13 +181,13 @@ deproto(protonum)
 	case 12: return "pup";
 	case 16: return "chaos";
 	case 17: return "udp";
-	default: (void) sprintf(nbuf, "%d", protonum); return (nbuf);
+	default: (void) sprintf(retbuf, "%d", protonum); return (retbuf);
 	}
 }
 
 static const u_char *
-do_rrset(msg, len, cp, cnt, pflag, file, hs)
-	int cnt, pflag, len;
+do_rrset(msg, cp, cnt, pflag, file, hs)
+	int cnt, pflag;
 	const u_char *cp, *msg;
 	const char *hs;
 	FILE *file;
@@ -190,7 +205,7 @@ do_rrset(msg, len, cp, cnt, pflag, file, hs)
 			fprintf(file, hs);
 		while (--n >= 0) {
 			if ((!_res.pfcode) || sflag) {
-				cp = __p_rr(cp, msg, file);
+				cp = p_rr(cp, msg, file);
 			} else {
 				unsigned int dlen;
 				cp += __dn_skipname(cp, cp + MAXCDNAME);
@@ -201,7 +216,7 @@ do_rrset(msg, len, cp, cnt, pflag, file, hs)
 				cp += INT16SZ;
 				cp += dlen;
 			}
-			if ((cp - msg) > len)
+			if ((cp - msg) > PACKETSZ)
 				return (NULL);
 		}
 		if ((!_res.pfcode) ||
@@ -218,7 +233,6 @@ __p_query(msg)
 	__fp_query(msg, stdout);
 }
 
-
 /*
  * Print the current options.
  * This is intended to be primarily a debugging routine.
@@ -253,9 +267,6 @@ __fp_nquery(msg, len, file)
 	register const HEADER *hp;
 	register int n;
 
-	if ((_res.options & RES_INIT) == 0 && res_init() == -1)
-		return;
-
 #define TruncTest(x) if (x >= endMark) goto trunc
 #define	ErrorTest(x) if (x == NULL) goto error
 
@@ -272,8 +283,7 @@ __fp_nquery(msg, len, file)
 			ntohs(hp->id));
 		putc('\n', file);
 	}
-	if ((!_res.pfcode) || (_res.pfcode & RES_PRF_HEADX))
-		putc(';', file);
+	putc(';', file);
 	if ((!_res.pfcode) || (_res.pfcode & RES_PRF_HEAD2)) {
 		fprintf(file, "; flags:");
 		if (hp->qr)
@@ -286,6 +296,8 @@ __fp_nquery(msg, len, file)
 			fprintf(file, " rd");
 		if (hp->ra)
 			fprintf(file, " ra");
+		if (hp->pr)
+			fprintf(file, " pr");
 	}
 	if ((!_res.pfcode) || (_res.pfcode & RES_PRF_HEAD1)) {
 		fprintf(file, "; Ques: %d", ntohs(hp->qdcount));
@@ -304,21 +316,9 @@ __fp_nquery(msg, len, file)
 		if ((!_res.pfcode) || (_res.pfcode & RES_PRF_QUES))
 			fprintf(file, ";; QUESTIONS:\n");
 		while (--n >= 0) {
-			if ((!_res.pfcode) || (_res.pfcode & RES_PRF_QUES))
-				fprintf(file, ";;\t");
+			fprintf(file, ";;\t");
 			TruncTest(cp);
-			if ((!_res.pfcode) || (_res.pfcode & RES_PRF_QUES))
-				cp = p_cdnname(cp, msg, len, file);
-			else {
-				int n;
-				char name[MAXDNAME];
-
-				if ((n = dn_expand(msg, msg+len, cp, name,
-						sizeof name)) < 0)
-					cp = NULL;
-				else
-					cp += n;
-			}
+			cp = p_cdname(cp, msg, file);
 			ErrorTest(cp);
 			TruncTest(cp);
 			if ((!_res.pfcode) || (_res.pfcode & RES_PRF_QUES))
@@ -330,15 +330,14 @@ __fp_nquery(msg, len, file)
 				fprintf(file, ", class = %s\n",
 					__p_class(_getshort((u_char*)cp)));
 			cp += INT16SZ;
-			if ((!_res.pfcode) || (_res.pfcode & RES_PRF_QUES))
-				putc('\n', file);
+			putc('\n', file);
 		}
 	}
 	/*
 	 * Print authoritative answer records
 	 */
 	TruncTest(cp);
-	cp = do_rrset(msg, len, cp, hp->ancount, RES_PRF_ANS, file,
+	cp = do_rrset(msg, cp, hp->ancount, RES_PRF_ANS, file,
 		      ";; ANSWERS:\n");
 	ErrorTest(cp);
 
@@ -346,7 +345,7 @@ __fp_nquery(msg, len, file)
 	 * print name server records
 	 */
 	TruncTest(cp);
-	cp = do_rrset(msg, len, cp, hp->nscount, RES_PRF_AUTH, file,
+	cp = do_rrset(msg, cp, hp->nscount, RES_PRF_AUTH, file,
 		      ";; AUTHORITY RECORDS:\n");
 	ErrorTest(cp);
 
@@ -354,7 +353,7 @@ __fp_nquery(msg, len, file)
 	/*
 	 * print additional records
 	 */
-	cp = do_rrset(msg, len, cp, hp->arcount, RES_PRF_ADD, file,
+	cp = do_rrset(msg, cp, hp->arcount, RES_PRF_ADD, file,
 		      ";; ADDITIONAL RECORDS:\n");
 	ErrorTest(cp);
 	return;
@@ -408,7 +407,7 @@ __p_fqname(cp, msg, file)
 	FILE *file;
 {
 	char name[MAXDNAME];
-	int n;
+	int n, len;
 
 	if ((n = dn_expand(msg, cp + MAXCDNAME, cp, name, sizeof name)) < 0)
 		return (NULL);
@@ -436,10 +435,6 @@ __p_rr(cp, msg, file)
 	u_int32_t tmpttl, t;
 	int lcnt;
 
-	if ((_res.options & RES_INIT) == 0 && res_init() == -1) {
-		h_errno = NETDB_INTERNAL;
-		return (NULL);
-	}
 	if ((cp = p_fqname(cp, msg, file)) == NULL)
 		return (NULL);			/* compression error */
 	type = _getshort((u_char*)cp);
@@ -452,7 +447,7 @@ __p_rr(cp, msg, file)
 	cp += INT16SZ;
 	cp1 = cp;
 	if ((!_res.pfcode) || (_res.pfcode & RES_PRF_TTLID))
-		fprintf(file, "\t%lu", (u_long)tmpttl);
+		fprintf(file, "\t%lu", tmpttl);
 	if ((!_res.pfcode) || (_res.pfcode & RES_PRF_CLASS))
 		fprintf(file, "\t%s", __p_class(class));
 	fprintf(file, "\t%s", __p_type(type));
@@ -521,19 +516,15 @@ __p_rr(cp, msg, file)
 			return (NULL);
 		fputs(" (\n", file);
 		t = _getlong((u_char*)cp);  cp += INT32SZ;
-		fprintf(file, "\t\t\t%lu\t; serial\n", (u_long)t);
+		fprintf(file, "\t\t\t%lu\t; serial\n", t);
 		t = _getlong((u_char*)cp);  cp += INT32SZ;
-		fprintf(file, "\t\t\t%lu\t; refresh (%s)\n",
-			(u_long)t, __p_time(t));
+		fprintf(file, "\t\t\t%lu\t; refresh (%s)\n", t, __p_time(t));
 		t = _getlong((u_char*)cp);  cp += INT32SZ;
-		fprintf(file, "\t\t\t%lu\t; retry (%s)\n",
-			(u_long)t, __p_time(t));
+		fprintf(file, "\t\t\t%lu\t; retry (%s)\n", t, __p_time(t));
 		t = _getlong((u_char*)cp);  cp += INT32SZ;
-		fprintf(file, "\t\t\t%lu\t; expire (%s)\n",
-			(u_long)t, __p_time(t));
+		fprintf(file, "\t\t\t%lu\t; expire (%s)\n", t, __p_time(t));
 		t = _getlong((u_char*)cp);  cp += INT32SZ;
-		fprintf(file, "\t\t\t%lu )\t; minimum (%s)",
-			(u_long)t, __p_time(t));
+		fprintf(file, "\t\t\t%lu )\t; minimum (%s)", t, __p_time(t));
 		break;
 
 	case T_MX:
@@ -664,6 +655,8 @@ __p_rr(cp, msg, file)
 	return (cp);
 }
 
+static	char nbuf[40];
+
 /*
  * Return a string for the type
  */
@@ -671,8 +664,6 @@ const char *
 __p_type(type)
 	int type;
 {
-	static char nbuf[20];
-
 	switch (type) {
 	case T_A:	return "A";
 	case T_NS:	return "NS";
@@ -722,8 +713,6 @@ const char *
 __p_class(class)
 	int class;
 {
-	static char nbuf[20];
-
 	switch (class) {
 	case C_IN:	return "IN";
 	case C_HS:	return "HS";
@@ -739,14 +728,12 @@ const char *
 __p_option(option)
 	u_long option;
 {
-	static char nbuf[40];
-
 	switch (option) {
 	case RES_INIT:		return "init";
 	case RES_DEBUG:		return "debug";
-	case RES_AAONLY:	return "aaonly(unimpl)";
+	case RES_AAONLY:	return "aaonly";
 	case RES_USEVC:		return "usevc";
-	case RES_PRIMARY:	return "primry(unimpl)";
+	case RES_PRIMARY:	return "primry";
 	case RES_IGNTC:		return "igntc";
 	case RES_RECURSE:	return "recurs";
 	case RES_DEFNAMES:	return "defnam";
@@ -754,8 +741,7 @@ __p_option(option)
 	case RES_DNSRCH:	return "dnsrch";
 	case RES_INSECURE1:	return "insecure1";
 	case RES_INSECURE2:	return "insecure2";
-	default:		sprintf(nbuf, "?0x%lx?", (u_long)option);
-				return (nbuf);
+	default:		sprintf(nbuf, "?0x%x?", option); return (nbuf);
 	}
 }
 
@@ -766,7 +752,6 @@ char *
 __p_time(value)
 	u_int32_t value;
 {
-	static char nbuf[40];
 	int secs, mins, hours, days;
 	register char *p;
 
