@@ -55,12 +55,11 @@
 
 #if defined(LIBC_SCCS) && !defined(lint)
 static char sccsid[] = "@(#)res_init.c	8.1 (Berkeley) 6/7/93";
-static char rcsid[] = "res_init.c,v 1.4 1995/05/26 04:18:56 hjl Exp";
+static char rcsid[] = "res_init.c,v 1.3 1995/05/06 14:12:41 hjl Exp";
 #endif /* LIBC_SCCS and not lint */
 
 #include <sys/param.h>
 #include <sys/socket.h>
-#include <sys/time.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <arpa/nameser.h>
@@ -72,36 +71,11 @@ static char rcsid[] = "res_init.c,v 1.4 1995/05/26 04:18:56 hjl Exp";
 #include <stdlib.h>
 #include <string.h>
 
-/*-------------------------------------- info about "sortlist" --------------
- * Marc Majka		1994/04/16
- * Allan Nathanson	1994/10/29 (BIND 4.9.3.x)
- *
- * NetInfo resolver configuration directory support.
- *
- * Allow a NetInfo directory to be created in the hierarchy which
- * contains the same information as the resolver configuration file.
- *
- * - The local domain name is stored as the value of the "domain" property.
- * - The Internet address(es) of the name server(s) are stored as values
- *   of the "nameserver" property.
- * - The name server addresses are stored as values of the "nameserver"
- *   property.
- * - The search list for host-name lookup is stored as values of the
- *   "search" property.
- * - The sortlist comprised of IP address netmask pairs are stored as
- *   values of the "sortlist" property. The IP address and optional netmask
- *   should be seperated by a slash (/) or ampersand (&) character.
- * - Internal resolver variables can be set from the value of the "options"
- *   property.
- */
-
 #include "res_options.h"
 
 static void res_setoptions __P((char *, char *));
 
 #ifdef RESOLVSORT
-static const char sort_mask[] = "/&";
-#define ISSORTMASK(ch) (strchr(sort_mask, ch) != NULL)
 static u_int32_t net_mask __P((struct in_addr));
 #endif
 
@@ -109,12 +83,11 @@ static u_int32_t net_mask __P((struct in_addr));
 # define isascii(c) (!(c & 0200))
 #endif
 
-#ifndef __ELF__
 /*
  * Resolver state default settings.
  */
+
 struct __res_state _res = {0};
-#endif
 
 /*
  * Set up default settings.  If the configuration file exist, the values
@@ -137,12 +110,11 @@ struct __res_state _res = {0};
  *
  * Return 0 if completes successfully, -1 on error
  */
-int
 res_init()
 {
 	register FILE *fp;
 	register char *cp, **pp;
-	register int n;
+	register int n, dots;
 	char buf[BUFSIZ];
 	int nserv = 0;    /* number of nameserver records read from file */
 	int haveenv = 0;
@@ -151,9 +123,6 @@ res_init()
 	int nsort = 0;
 	char *net;
 #endif
-#ifndef RFC1535
-	int dots;
-#endif
 
 	/*
 	 * These three fields used to be statically initialized.  This made
@@ -167,26 +136,15 @@ res_init()
 	 * will follow.  Zero for any of these fields would make no sense,
 	 * so one can safely assume that the applications were already getting
 	 * unexpected results.
-	 *
-	 * _res.options is tricky since some apps were known to diddle the bits
-	 * before res_init() was first called. We can't replicate that semantic
-	 * with dynamic initialization (they may have turned bits off that are
-	 * set in RES_DEFAULT).  Our solution is to declare such applications
-	 * "broken".  They could fool us by setting RES_INIT but none do (yet).
 	 */
 	if (!_res.retrans)
 		_res.retrans = RES_TIMEOUT;
 	if (!_res.retry)
 		_res.retry = 4;
+	/* It is possible to _res.options to be set by sethostent ().
+	 * We need to cover that. */
 	if (!(_res.options & RES_INIT))
-		_res.options = RES_DEFAULT;
-
-	/*
-	 * This one used to initialize implicitly to zero, so unless the app
-	 * has set it to something in particular, we can randomize it now.
-	 */
-	if (!_res.id)
-		_res.id = res_randomid();
+		_res.options |= RES_DEFAULT;
 
 #ifdef USELOOPBACK
 	_res.nsaddr.sin_addr = inet_makeaddr(IN_LOOPBACKNET, 1);
@@ -238,9 +196,6 @@ res_init()
 	(line[sizeof(name) - 1] == ' ' || \
 	 line[sizeof(name) - 1] == '\t'))
 
-#ifdef	NeXT
-	if (netinfo_res_init(&haveenv, &havesearch) == 0)
-#endif
 	if ((fp = fopen(_PATH_RESCONF, "r")) != NULL) {
 	    /* read the config file */
 	    while (fgets(buf, sizeof(buf), fp) != NULL) {
@@ -325,18 +280,17 @@ res_init()
 			if (*cp == '\0' || *cp == '\n' || *cp == ';')
 			    break;
 			net = cp;
-			while (*cp && !ISSORTMASK(*cp) && *cp != ';' &&
+			while (*cp && *cp != '/' &&
 			       isascii(*cp) && !isspace(*cp))
 				cp++;
 			n = *cp;
 			*cp = 0;
 			if (inet_aton(net, &a)) {
 			    _res.sort_list[nsort].addr = a;
-			    if (ISSORTMASK(n)) {
+			    if (n == '/') {
 				*cp++ = n;
 				net = cp;
-				while (*cp && *cp != ';' &&
-					isascii(*cp) && !isspace(*cp))
+				while (*cp && isascii(*cp) && !isspace(*cp))
 				    cp++;
 				n = *cp;
 				*cp = 0;
@@ -352,7 +306,7 @@ res_init()
 			    }
 			    nsort++;
 			}
-			*cp = n;
+			*cp++ = n;
 		    }
 		    continue;
 		}
@@ -457,7 +411,6 @@ res_setoptions(options, source)
 }
 
 #ifdef RESOLVSORT
-/* XXX - should really support CIDR which means explicit masks always. */
 static u_int32_t
 net_mask(in)		/* XXX - should really use system's version of this */
 	struct in_addr in;
@@ -471,12 +424,3 @@ net_mask(in)		/* XXX - should really use system's version of this */
 	return (htonl(IN_CLASSC_NET));
 }
 #endif
-
-u_int16_t
-res_randomid()
-{
-	struct timeval now;
-
-	gettimeofday(&now, NULL);
-	return (0xffff & (now.tv_sec ^ now.tv_usec ^ getpid()));
-}
