@@ -55,7 +55,7 @@
 
 #if defined(LIBC_SCCS) && !defined(lint)
 static char sccsid[] = "@(#)res_query.c	8.1 (Berkeley) 6/4/93";
-static char rcsid[] = "res_query.c,v 1.3 1995/05/25 05:22:46 hjl Exp";
+static char rcsid[] = "res_query.c,v 1.2 1995/05/06 14:12:43 hjl Exp";
 #endif /* LIBC_SCCS and not lint */
 
 #include <sys/param.h>
@@ -79,17 +79,9 @@ static char rcsid[] = "res_query.c,v 1.3 1995/05/25 05:22:46 hjl Exp";
 #define MAXPACKET	1024
 #endif
 
-#ifndef __ELF__
-#define __hostalias hostalias
-#endif
-
 char *__hostalias __P((const char *));
 int h_errno;
 
-#ifdef __ELF__
-#pragma weak hostalias = __hostalias
-#endif
-
 /*
  * Formulate a normal query, send, and await answer.
  * Returned answer is placed in supplied buffer "answer".
@@ -326,10 +318,6 @@ res_querydomain(name, domain, class, type, answer, anslen)
 	const char *longname = nbuf;
 	int n;
 
-	if ((_res.options & RES_INIT) == 0 && res_init() == -1) {
-		h_errno = NETDB_INTERNAL;
-		return (-1);
-	}
 #ifdef DEBUG
 	if (_res.options & RES_DEBUG)
 		printf(";; res_querydomain(%s, %s, %d, %d)\n",
@@ -362,12 +350,9 @@ __hostalias(name)
 	char buf[BUFSIZ];
 	static char abuf[MAXDNAME];
 
-	if (_res.options & RES_NOALIASES)
-		return (NULL);
 	file = getenv("HOSTALIASES");
 	if (file == NULL || (fp = fopen(file, "r")) == NULL)
 		return (NULL);
-	setbuf(fp, NULL);
 	buf[sizeof(buf) - 1] = '\0';
 	while (fgets(buf, sizeof(buf), fp)) {
 		for (cp1 = buf; *cp1 && !isspace(*cp1); ++cp1)
