@@ -8,7 +8,7 @@
 #include <gnu-stabs.h>
 
 #if 1
-function_alias(_cleanup, _IO_cleanup, void, (),
+function_alias(_cleanup, _IO_flush_all, void, (),
 		DEFUN_VOID(_cleanup))
 #else
 /* We don't want this since we are building the shared library.
