@@ -27,7 +27,7 @@ Cambridge, MA 02139, USA.  */
 
 char *__progname = (char *) "";
 
-void
+static void
 __init_misc (argc, argv, envp)
      int argc;
      char **argv;
