@@ -30,26 +30,15 @@ DEFUN(__isinfl, (value), long double value)
   union ieee854_double *u = (union ieee854_double *) &value;
 
   /* An IEEE 854 infinity has an exponent with the
-     maximum possible value and a mantissa of 0x8000000000000000.
-     For the 68881 the integer bit is dont-care.  */
+     maximum possible value and a zero mantissa.  */
   if ((u->ieee.exponent & 0x7fff) == 0x7fff &&
-#ifdef __mc68000__
-      (u->ieee.mantissa0 & 0x7fffffff) == 0 &&
-#else
-      u->ieee.mantissa0 == 0x80000000 &&
-#endif
-      u->ieee.mantissa1 == 0)
+      u->ieee.mantissa0 == 0 && u->ieee.mantissa1 == 0)
     return u->ieee.negative ? -1 : 1;
 
   return 0;
 }
 
 #include <gnu-stabs.h>
-#ifdef __ELF__
 #ifdef weak_alias
 weak_alias (__isinfl, isinfl);
 #endif
-#else
-function_alias(isinfl, __isinfl, int, (value),
-	       DEFUN(isinfl, (value), long double value));
-#endif
