@@ -29,22 +29,12 @@ DEFUN(__isnanl, (value), long double value)
   union ieee854_double *u = (union ieee854_double *) &value;
 
   /* IEEE 854 NaN's have the maximum possible
-     exponent and a nonzero mantissa.  For
-     the 68881 the integer bit is dont-care.  */
-  return ((u->ieee_nan.exponent & 0x7fff) == 0x7fff &&
-#ifndef __mc68000__
-	  u->ieee_nan.one != 0 &&
-#endif
-	  (u->ieee_nan.mantissa0 != 0 || u->ieee_nan.mantissa1 != 0 ||
-	   u->ieee_nan.quiet_nan != 0));
+     exponent and a nonzero mantissa.  */
+  return ((u->ieee.exponent & 0x7fff) == 0x7fff &&
+	  (u->ieee.mantissa0 != 0 || u->ieee.mantissa1 != 0));
 }
 
 #include <gnu-stabs.h>
-#ifdef __ELF__
 #ifdef weak_alias
 weak_alias (__isnanl, isnanl);
 #endif
-#else
-function_alias(isnanl,__isnanl, int, (value),
-	       DEFUN(isinfl, (value), long double value));
-#endif
