@@ -33,15 +33,11 @@ DEFUN(__isqnanl, (value), long double value)
      is quiet the highest bit in the mantissa
      is set.  */
   return ((u->ieee_nan.exponent & 0x7fff) == 0x7fff &&
-	  (u->ieee_nan.quiet_nan == 1) && (u->ieee_nan.one == 1));
+	  (u->ieee_nan.quiet_nan == 1) &&
+	  (u->ieee_nan.mantissa0 != 0 || u->ieee_nan.mantissa1 != 0));
 }
 
 #include <gnu-stabs.h>
-#ifdef __ELF__
 #ifdef weak_alias
 weak_alias (__isqnanl, isqnanl);
 #endif
-#else
-function_alias(isqnanl,__isqnanl, int, (value),
-	       DEFUN(isinfl, (value), long double value));
-#endif
