@@ -31,16 +31,11 @@ DEFUN(__issnanl, (value), long double value)
   /* IEEE 854 NaN's have the maximum possible
      exponent and a nonzero mantissa.  */
   return ((u->ieee_nan.exponent & 0x7fff) == 0x7fff &&
-	  (u->ieee_nan.quiet_nan == 0) && (u->ieee_nan.one == 1) &&
+	  (u->ieee_nan.quiet_nan == 0) &&
 	  (u->ieee_nan.mantissa0 != 0 || u->ieee_nan.mantissa1 != 0));
 }
 
 #include <gnu-stabs.h>
-#ifdef __ELF__
 #ifdef weak_alias
 weak_alias (__issnanl, issnanl);
 #endif
-#else
-function_alias(issnanl,__issnanl, int, (value),
-	       DEFUN(isinfl, (value), long double value));
-#endif
