@@ -2,12 +2,8 @@
 #include <errno.h>
 #include <sys/stat.h>
 
-#ifdef __SVR4_I386_ABI_L1__
-#define prev_lstat	__prev_lstat
-#else
 static inline
 _syscall2(int,prev_lstat,const char *,path, struct stat *,statbuf)
-#endif
 
 int
 _lxstat(int version, const char * path, struct stat * statbuf)
