@@ -8,7 +8,7 @@ _syscall2(long,socketcall,int,call,unsigned long *,args);
 /* send, sendto added by bir7@leland.stanford.edu */
 
 int
-send (int sockfd, const void *buffer, size_t len, unsigned flags)
+send (int sockfd, const void *buffer, int len, unsigned flags)
 {
   unsigned long args[4];
   args[0] = sockfd;
