@@ -19,18 +19,46 @@ Cambridge, MA 02139, USA.  */
 #include <ansidecl.h>
 #include <stddef.h>
 
+#ifdef __ELF__
+#include <gnu-stabs.h>
+
+#if !defined(__PIC__) && !defined(__pic__)
+/* We use this to make sure the __libc_subinit section is always
+ * there for the static libraries. We may try weak symbol later. */
+static void
+__init_dummy ()
+{
+}
+
+text_set_element (__libc_subinit, __init_dummy);
+
+#endif
+#else
 struct
   {
     size_t n;
     void EXFUN((*fn[0]), (int argc, char **argv, char **envp));
   } __libc_subinit;
+#endif
 
 void
 DEFUN(__libc_init, (argc, argv, envp),
       int argc AND char **argv AND char **envp)
 {
+#ifdef __ELF__
+  typedef EXFUN((*__libc_subinit_t),
+	(int argc, char **argv, char **envp));
+  __libc_subinit_t *fp;
+  symbol_set_declare (__libc_subinit);
+
+  for (fp = (__libc_subinit_t *)
+	(symbol_set_first_element (__libc_subinit));
+	!symbol_set_end_p (__libc_subinit, fp); fp++)
+    (*fp[0]) (argc, argv, envp);
+#else
   size_t i;
 
   for (i = 0; i < __libc_subinit.n; ++i)
     (*__libc_subinit.fn[i]) (argc, argv, envp);
+#endif
 }
